pub unsafe extern "C" fn vampire_get_refutation() -> *mut vampire_unit_tExpand description
Get the refutation (proof) after a successful vampire_prove() call. @return The empty clause with inference chain, or NULL if no proof
pub unsafe extern "C" fn vampire_get_refutation() -> *mut vampire_unit_tGet the refutation (proof) after a successful vampire_prove() call. @return The empty clause with inference chain, or NULL if no proof